GraphqlAdapter<TModel extends Model> class abstract mixin

Constructors that convert app models to and from REST

Constructors

GraphqlAdapter()

Properties

fieldsToGraphqlRuntimeDefinition Map<String, RuntimeGraphqlDefinition>
A map of Dart field names to their RuntimeGraphqlDefinition
no setter
hashCode int
The hash code for this object.
no setterinherited
queryOperationTransformer GraphqlQueryOperationTransformer Function(Query?, GraphqlModel?)?
The transformer to change a Query to a GraphqlOperation
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromGraphql(Map<String, dynamic> input, {required GraphqlProvider provider, ModelRepository<GraphqlModel>? repository}) Future<TModel>
Deserialize from GraphQL
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toGraphql(TModel input, {required GraphqlProvider provider, ModelRepository<GraphqlModel>? repository}) Future<Map<String, dynamic>>
Serialize to GraphQL
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited