RuntimeGraphqlDefinition class
Used to define types in GraphqlAdapter#fieldsToGraphqlRuntimeDefinition. The build runner package
extracts types and associations that would've been otherwise inaccessible at runtime.
Constructors
-
RuntimeGraphqlDefinition({bool association = false, required String documentNodeName, bool iterable = false, Map<
String, Map< subfields = const <String, Map<String, dynamic>>{}, required Type type})String, dynamic> > -
Used to define types in
GraphqlAdapter#fieldsToGraphqlRuntimeDefinition. The build runner package extracts types and associations that would've been otherwise inaccessible at runtime.const
Properties
- association → bool
-
Whether this column relates to another GraphqlModel
This is true for
Iterable<GraphqlModel>andGraphqlModel. Defaults tofalse.final - documentNodeName → String
-
The GraphQL document field node, not the field name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iterable → bool
-
Whether this column is any subset
Iterable(e.g.List,Set). Defaults tofalse.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subfields
→ Map<
String, Map< String, dynamic> > -
For fields that are not strictly associations but have nested attributes,
subfields needs to be defined for the GraphQL query to resolve.
final
- type → Type
-
The type accessed after the result is retrieved, not the GraphQL type.
In other words, the runtime type.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited